@@ -4,6 +4,10 @@ import jax
 
 
 class sliceable_deque(deque):
+    r"""A class implemented slice for collections.deque
+    
+    Reference: https://stackoverflow.com/questions/10003143/how-to-slice-a-deque
+    """
     def __getitem__(self, index):
         if isinstance(index, slice):
             return type(self)(islice(self, index.start,
@@ -14,4 +18,4 @@ jax.tree_util.register_pytree_node(
   sliceable_deque,
   flatten_func=lambda sd: (sd, None),
   unflatten_func=lambda treedef, leaves: sliceable_deque(leaves)
-)
\ No newline at end of file
+)
